@@ -7,8 +7,7 @@
 
  * Author: Ralph Amissah
 
- * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008 Ralph Amissah All Rights Reserved.
+ * Copyright: (C) 1997 - 2009 Ralph Amissah All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -1103,7 +1102,8 @@ WOK
       while string =~/(http:\/\/\S+?)(?:<=tilde>\S+)+/ #tilde in urls \href treated differently from text
         string.gsub!(/(http:\/\/\S+?)(?:<=tilde>(\S+))+/,'\1~\2')
       end
-      string.gsub!(/<=tilde>/,'{$\sim$}')
+      string.gsub!(/<=tilde>/,'{$\tilde$}')
+      #string.gsub!(/<=tilde>/,'{$\sim$}')
       string.gsub!(/<=pipe>/,'{\textbar}')
       string.gsub!(/<=caret>/,'{\^{~}}')
       #string.gsub!(/<=caret>/,'\^{}')
@@ -1211,6 +1211,12 @@ WOK
       else string.gsub!(/&/,'<=amp>')
       #else string.gsub!(/(\s+&\s+)/,' and ')
       end
+      if @@flag_code;
+        string.gsub!(/\\~(\\\{)/,'{$\tilde$}\1')
+        string.gsub!(/(\\\})\\~/,'\1{$\tilde$}')
+        string.gsub!(/\\~(\[)/,'{$\tilde$}\1')
+        string.gsub!(/(\])\\~/,'\1{$\tilde$}')
+      end
       string.gsub!(/§/u,'\S') #latex: space between next character not preserved? #string.gsub!(/§ /,'\S ')
       string.gsub!(/£/u,'\pounds')
       string.gsub!(/&\S+?;/,' ')
@@ -1283,7 +1289,8 @@ WOK
       while string =~/(http:\/\/\S+?)(?:<=tilde>\S+)+/ #tilde in urls \href treated differently from text
         string.gsub!(/(http:\/\/\S+?)(?:<=tilde>(\S+))+/,'\1~\2')
       end
-      string.gsub!(/<=tilde>/,'{$\sim$}')
+      string.gsub!(/<=tilde>/,'{$\tilde$}')
+      #string.gsub!(/<=tilde>/,'{$\sim$}')
       string.gsub!(/<=pipe>/,'{\textbar}')
       string.gsub!(/<=caret>/,'{\^{~}}')
       #string.gsub!(/<=caret>/,'\^{}')
